==> gammaray_2.3.0.orig.tar.gz: gammaray-2.3.0/tests/manual/propertytest.cpp <==
/*
  propertytest.cpp

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <QCoreApplication>
#include <QTimer>
#include <QVariant>

class MyTestObject : public QObject
{
  Q_OBJECT
  Q_PROPERTY(int staticChangingProperty READ staticChangingProperty RESET staticChangingPropertyReset NOTIFY staticChangingPropertyChanged)
public:
  explicit MyTestObject(QObject *parent = 0) : QObject(parent), m_count(0)
  {
    setObjectName("propertyTestObject");
    QTimer *timer = new QTimer(this);
    connect(timer, SIGNAL(timeout()), this, SLOT(timeout()));
    timer->start(5000);
  }

  int staticChangingProperty() { return m_count; }
  void staticChangingPropertyReset()
  {
    m_count = 0;
    emit staticChangingPropertyChanged();
  }

signals:
  void staticChangingPropertyChanged();

private slots:
  void timeout()
  {
    ++m_count;
    setProperty("dynamicChangingProperty", m_count);
    emit staticChangingPropertyChanged();
  }

private:
  int m_count;

};

int main(int argc, char** argv)
{
  QCoreApplication app(argc, argv);
  MyTestObject obj;
  return app.exec();
}

#include "propertytest.moc"

==> gammaray_2.9.0.orig.tar.gz: gammaray-2.9.0/tests/manual/propertytest.cpp <==
/*
  propertytest.cpp

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <QCoreApplication>
#include <QTimer>

#include "../shared/propertytestobject.h"

int main(int argc, char **argv)
{
    QCoreApplication app(argc, argv);
    PropertyTestObject obj;
    QTimer timer;
    QObject::connect(&timer, SIGNAL(timeout()), obj.changingPropertyObject(),
                     SLOT(changeProperties()));
    timer.start(5000);

    return app.exec();
}
